@@ -4,6 +4,7 @@ import time
 import pytz
 import json
 import sys
+import functools
 
 if sys.version_info >= (3, 0):
     unicode = lambda x: str(x)
@@ -11,13 +12,14 @@ if sys.version_info >= (3, 0):
 
 def validator(fn):
     fn_name = fn.func_name if hasattr(fn, 'func_name') else fn.__name__
-    if fn_name is 'inflate':
+    if fn_name == 'inflate':
         exc_class = InflateError
     elif fn_name == 'deflate':
         exc_class = DeflateError
     else:
-        raise Exception("Unknown Property method " + fn.func_name)
+        raise Exception("Unknown Property method " + fn_name)
 
+    @functools.wraps(fn)
     def validator(self, value, node_id=None):
         try:
             return fn(self, value)
