@@ -5,12 +5,6 @@ from .exception import UniqueProperty, DataInconsistencyError
 camel_to_upper = lambda x: "_".join(word.upper() for word in re.split(r"([A-Z][0-9a-z]*)", x)[1::2])
 upper_to_camel = lambda x: "".join(word.title() for word in x.split("_"))
 
-def items(_dict):
-    try:
-        return _dict.iteritems()
-    except AttributeError:
-        return _dict.items()
-
 
 class CustomBatch(neo4j.WriteBatch):
 
@@ -64,7 +58,7 @@ class CustomBatch(neo4j.WriteBatch):
 
 
 def _legacy_conflict_check(cls, node, props):
-    for key, value in items(props):
+    for key, value in props.items():
         if key in cls._class_properties() and cls.get_property(key).unique_index:
                 results = cls.index.__index__.get(key, value)
                 if len(results):
